@@ -61,15 +61,18 @@ def create(output):
 @click.argument('sparql_endpoint')
 @click.option(
     '-u', '--dataset-uri', default='https://w3id.org/d2s/distribution/default', 
-    help='URI of the dataset distribution')
+    help='URI of the dataset distribution to describe')
 @click.option(
     '-o', '--output', default='', 
     help='Write RDF to output file')
+@click.option(
+    '-m', '--metadata-type', default='hcls', 
+    help='Type of metadata to generate (hcls, bio2rdf). Default is hcls')
 @click.option(
     '-g', '--graph', default='', 
-    help='Compute metadata only for specified graph')
-def analyze(sparql_endpoint, dataset_uri, output, graph):
-    g = generate_hcls_from_sparql(sparql_endpoint, dataset_uri, graph)
+    help='Compute metadata only for the specified graph in the triplestore (compute for all graphs by default)')
+def analyze(sparql_endpoint, dataset_uri, output, metadata_type, graph):
+    g = generate_hcls_from_sparql(sparql_endpoint, dataset_uri, metadata_type, graph)
     if output:
         g.serialize(destination=output, format='turtle')
         print("Metadata stored to " + output + ' 📝')
